==> nextcloud-14.0.1.tgz: nextcloud/apps/files_external/l10n/nb.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Ekstern lagring",
    "Personal" : "Personlig",
    "System" : "System",
    "Grant access" : "Gi tilgang",
    "Error configuring OAuth1" : "Feil ved oppsett av OAuth1",
    "Please provide a valid app key and secret." : "Oppgi gyldig programnøkkel og hemmelighet.",
    "Error configuring OAuth2" : "Feil ved oppsett av OAuth2",
    "Generate keys" : "Generer nøkler",
    "Error generating key pair" : "Feil ved nøkkelgenerering",
    "All users. Type to select user or group." : "Alle brukere. Tast for å velge bruker eller gruppe.",
    "(group)" : "(gruppe)",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibelt med Mac NFD koding (treg)",
    "Admin defined" : "Admin-definert",
    "Are you sure you want to delete this external storage?" : "Er du sikker på at du ønsker å slette dette eksterne lageret?",
    "Delete storage?" : "Slett lagringsplass",
    "Saved" : "Lagret",
    "Saving..." : "Lagrer …",
    "Save" : "Lagre",
    "Empty response from the server" : "Tomt svar fra tjeneren",
    "Couldn't access. Please log out and in again to activate this mount point" : "Fikk ikke tilgang. Logg ut og inn igjen for å aktivere dette oppkoblingspunktet.",
    "Couldn't get the information from the remote server: {code} {type}" : "Kunne ikke få informasjon fra fjerntjeneren/ remote server: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Klarte ikke å hente listen over eksterne oppkoblingspunkter: {type}",
    "There was an error with message: " : "Det oppstod en feil med melding: ",
    "External mount error" : "Ekstern oppkoblingsfeil",
    "external-storage" : "eksternlagring",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Klarte ikke å hente listen over oppkoblingspunkter for Windowsnettverks-disker: Tomt svar fra tjeneren",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Noen av de oppsatte eksterne oppkoblingspunktene er ikke tilkoblet. Klikk på de røde raden(e) for mer informasjon.",
    "Please enter the credentials for the {mount} mount" : "Legg inn påloggingsdetaljer for {mount}",
    "Username" : "Brukernavn",
    "Password" : "Passord",
    "Credentials saved" : "Påloggingsdetaljer lagret",
    "Credentials saving failed" : "Lagring av påloggingsdetaljer mislyktes",
    "Credentials required" : "Påloggingsdetaljer kreves",
    "Storage with ID \"%d\" not found" : "Lager med ID \"%d\" ikke funnet",
    "Invalid backend or authentication mechanism class" : "Ugyldig bakende eller type autentiseringsmekanisme",
    "Invalid mount point" : "Ugyldig oppkoblingspunkt",
    "Objectstore forbidden" : "Objektlager forbudt",
    "Invalid storage backend \"%s\"" : "Ugyldig lagringstjener \"%s\"",
    "Not permitted to use backend \"%s\"" : "Bruk av bakenden \"%s\" tillates ikke",
    "Not permitted to use authentication mechanism \"%s\"" : "Du tillates ikke å bruke autentiseringsmekanismen \"%s\"",
    "Unsatisfied backend parameters" : "Noen bakende-parameter mangler",
    "Unsatisfied authentication mechanism parameters" : "Noen parametre for autentiseringsmekanisme mangler",
    "Insufficient data: %s" : "Utilstrekkelige data: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Lager med ID \"%d\" kan ikke redigeres av bruker",
    "Access key" : "Tilgangsnøkkel",
    "Secret key" : "Hemmelig nøkkel",
    "Builtin" : "Innebygget",
    "None" : "Ingen",
    "OAuth1" : "OAuth1",
    "App key" : "Program-nøkkel",
    "App secret" : "Program-hemmelighet",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klient-ID",
    "Client secret" : "Klient-hemmelighet",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "Prosjektnavn",
    "Identity endpoint URL" : "URL for identitets-endepunkt",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domene",
    "Rackspace" : "Rackspace",
    "API key" : "API-nøkkel",
    "Global credentials" : "Globale pålogginsdetaljer",
    "Log-in credentials, save in database" : "Påloggingsdetaljer, lagre i databasen",
    "Username and password" : "Brukernavn og passord",
    "Log-in credentials, save in session" : "Påloggingsdetaljer, lagre i økten",
    "User entered, store in database" : "Brukerangitt, lagre i databasen",
    "RSA public key" : "Offentlig RSA-nøkkel",
    "Public key" : "Offentlig nøkkel",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bøtte",
    "Hostname" : "Tjenernavn",
    "Port" : "Port",
    "Region" : "Området",
    "Enable SSL" : "Aktiver SSL",
    "Enable Path Style" : "Aktiver Path Style",
    "Legacy (v2) authentication" : "Foreldet (v2-) autentisering",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Ekstern undermappe",
    "Secure https://" : "Sikker https://",
    "FTP" : "FTP",
    "Host" : "Tjener",
    "Secure ftps://" : "Sikker ftps://",
    "Local" : "Lokal",
    "Location" : "Sted",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Rot",
    "SFTP with secret key login" : "SFTP med hemmelig nøkkel for pålogging",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Delt ressurs",
    "SMB / CIFS using OC login" : "SMB / CIFS med OC-pålogging",
    "Username as share" : "Brukernavn som delt ressurs",
    "OpenStack Object Storage" : "OpenStack objektlager",
    "Service name" : "Tjenestenavn",
    "Request timeout (seconds)" : "Tidsavbrudd for forespørsel (sekunder)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Merk:</b> Støtte for cURL i PHP er ikke aktivert eller installert. Oppkobling av %s er ikke mulig. Be systemadministratoren om å installere det.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Merk:</b> FTP-støtte i PHP er ikke slått på eller installert. Kan ikke koble opp %s. Ta kontakt med systemadministratoren for å få dette installert.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" er ikke installert. Oppkobling av %s er ikke mulig. Spør din systemadministrator om å installere det.",
    "External storage support" : "Støtte for ekstern lagring",
    "Name" : "Navn",
    "Storage type" : "Lagringstype",
    "Scope" : "Omfang",
    "Enable encryption" : "Aktiver kryptering",
    "Enable previews" : "Tillat fohåndsvisning",
    "Enable sharing" : "Aktiver deling",
    "Check for changes" : "Se etter endringer",
    "Never" : "Aldri",
    "Once every direct access" : "En gang pr. direkte tilgang",
    "Folder name" : "Mappenavn",
    "External storage" : "Ekstern lagringsplass",
    "Authentication" : "Autentisering",
    "Configuration" : "Oppsett",
    "Available for" : "Tilgjengelig for",
    "Click to recheck the configuration" : "Klikk for å sjekke oppsettet igjen",
    "Add storage" : "Legg til lagringsplass",
    "Advanced settings" : "Avanserte innstillinger",
    "Allow users to mount external storage" : "Tillat at brukere kobler opp eksterne lagre",
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Henting av henvendelsessymboler mislyktes. Sjekk at programnøkkelen og hemmeligheten din stemmer. ",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Henting av adgangssymboler mislyktes. Sjekk at programnøkkelen og hemmeligheten din stemmer.",
    "Step 1 failed. Exception: %s" : "Steg 1 mislyktes. Unntak: %s",
    "Step 2 failed. Exception: %s" : "Steg 2 mislyktes. Unntak: %s",
    "Dropbox App Configuration" : "Oppsett for Dropbox-program",
    "Google Drive App Configuration" : "Oppsett av Google Drive-program",
    "OpenStack" : "OpenStack",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "No external storage configured" : "Eksternt lager er ikke konfigurert",
    "You can add external storages in the personal settings" : "Du kan legge til eksterne lagre i personlige innstillinger",
    "Delete" : "Slett",
    "Allow users to mount the following external storage" : "Tillat brukere å koble opp følgende eksterne lagring",
    "Are you sure you want to delete this external storage" : "Er du sikker på at du vil slette denne eksterne lagringsplassen?"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5p1.tgz: nextcloud/apps/files_external/l10n/nb.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Ekstern lagring",
    "Personal" : "Personlig",
    "System" : "System",
    "Grant access" : "Gi tilgang",
    "Error configuring OAuth1" : "Feil ved oppsett av OAuth1",
    "Please provide a valid app key and secret." : "Oppgi gyldig programnøkkel og hemmelighet.",
    "Error configuring OAuth2" : "Feil ved oppsett av OAuth2",
    "Generate keys" : "Generer nøkler",
    "Error generating key pair" : "Feil ved nøkkelgenerering",
    "All users. Type to select user or group." : "Alle brukere. Tast for å velge bruker eller gruppe.",
    "(group)" : "(gruppe)",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibelt med Mac NFD koding (treg)",
    "Enable encryption" : "Aktiver kryptering",
    "Enable previews" : "Tillat fohåndsvisning",
    "Enable sharing" : "Aktiver deling",
    "Check for changes" : "Se etter endringer",
    "Never" : "Aldri",
    "Once every direct access" : "En gang pr. direkte tilgang",
    "Delete" : "Slett",
    "Admin defined" : "Admin-definert",
    "Are you sure you want to delete this external storage?" : "Er du sikker på at du ønsker å slette dette eksterne lageret?",
    "Delete storage?" : "Slett lagringsplass",
    "Saved" : "Lagret",
    "Saving..." : "Lagrer …",
    "Save" : "Lagre",
    "Empty response from the server" : "Tomt svar fra tjeneren",
    "Couldn't access. Please log out and in again to activate this mount point" : "Fikk ikke tilgang. Logg ut og inn igjen for å aktivere dette oppkoblingspunktet.",
    "Couldn't get the information from the remote server: {code} {type}" : "Kunne ikke få informasjon fra fjerntjeneren/ remote server: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Klarte ikke å hente listen over eksterne oppkoblingspunkter: {type}",
    "There was an error with message: " : "Det oppstod en feil med melding: ",
    "External mount error" : "Ekstern oppkoblingsfeil",
    "external-storage" : "eksternlagring",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Klarte ikke å hente listen over oppkoblingspunkter for Windowsnettverks-disker: Tomt svar fra tjeneren",
    "Please enter the credentials for the {mount} mount" : "Legg inn påloggingsdetaljer for {mount}",
    "Username" : "Brukernavn",
    "Password" : "Passord",
    "Credentials saved" : "Påloggingsdetaljer lagret",
    "Credentials saving failed" : "Lagring av påloggingsdetaljer mislyktes",
    "Credentials required" : "Påloggingsdetaljer kreves",
    "Storage with ID \"%d\" not found" : "Lager med ID \"%d\" ikke funnet",
    "Invalid backend or authentication mechanism class" : "Ugyldig bakende eller type autentiseringsmekanisme",
    "Invalid mount point" : "Ugyldig oppkoblingspunkt",
    "Objectstore forbidden" : "Objektlager forbudt",
    "Invalid storage backend \"%s\"" : "Ugyldig lagringstjener \"%s\"",
    "Not permitted to use backend \"%s\"" : "Bruk av bakenden \"%s\" tillates ikke",
    "Not permitted to use authentication mechanism \"%s\"" : "Du tillates ikke å bruke autentiseringsmekanismen \"%s\"",
    "Unsatisfied backend parameters" : "Noen bakende-parameter mangler",
    "Unsatisfied authentication mechanism parameters" : "Noen parametre for autentiseringsmekanisme mangler",
    "Insufficient data: %s" : "Utilstrekkelige data: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Lager med ID \"%d\" kan ikke redigeres av bruker",
    "Access key" : "Tilgangsnøkkel",
    "Secret key" : "Hemmelig nøkkel",
    "Builtin" : "Innebygget",
    "None" : "Ingen",
    "OAuth1" : "OAuth1",
    "App key" : "Program-nøkkel",
    "App secret" : "Program-hemmelighet",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klient-ID",
    "Client secret" : "Klient-hemmelighet",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "Prosjektnavn",
    "Identity endpoint URL" : "URL for identitets-endepunkt",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domene",
    "Rackspace" : "Rackspace",
    "API key" : "API-nøkkel",
    "Global credentials" : "Globale pålogginsdetaljer",
    "Log-in credentials, save in database" : "Påloggingsdetaljer, lagre i databasen",
    "Username and password" : "Brukernavn og passord",
    "Log-in credentials, save in session" : "Påloggingsdetaljer, lagre i økten",
    "User entered, store in database" : "Brukerangitt, lagre i databasen",
    "RSA public key" : "Offentlig RSA-nøkkel",
    "Public key" : "Offentlig nøkkel",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bøtte",
    "Hostname" : "Tjenernavn",
    "Port" : "Port",
    "Region" : "Området",
    "Enable SSL" : "Aktiver SSL",
    "Enable Path Style" : "Aktiver Path Style",
    "Legacy (v2) authentication" : "Foreldet (v2-) autentisering",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Ekstern undermappe",
    "Secure https://" : "Sikker https://",
    "FTP" : "FTP",
    "Host" : "Tjener",
    "Secure ftps://" : "Sikker ftps://",
    "Local" : "Lokal",
    "Location" : "Sted",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Rot",
    "SFTP with secret key login" : "SFTP med hemmelig nøkkel for pålogging",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Delt ressurs",
    "SMB / CIFS using OC login" : "SMB / CIFS med OC-pålogging",
    "Username as share" : "Brukernavn som delt ressurs",
    "OpenStack Object Storage" : "OpenStack objektlager",
    "Service name" : "Tjenestenavn",
    "Request timeout (seconds)" : "Tidsavbrudd for forespørsel (sekunder)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Merk:</b> Støtte for cURL i PHP er ikke aktivert eller installert. Oppkobling av %s er ikke mulig. Be systemadministratoren om å installere det.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Merk:</b> FTP-støtte i PHP er ikke slått på eller installert. Kan ikke koble opp %s. Ta kontakt med systemadministratoren for å få dette installert.",
    "External storage support" : "Støtte for ekstern lagring",
    "Name" : "Navn",
    "Storage type" : "Lagringstype",
    "Scope" : "Omfang",
    "Folder name" : "Mappenavn",
    "External storage" : "Ekstern lagringsplass",
    "Authentication" : "Autentisering",
    "Configuration" : "Oppsett",
    "Available for" : "Tilgjengelig for",
    "Click to recheck the configuration" : "Klikk for å sjekke oppsettet igjen",
    "Add storage" : "Legg til lagringsplass",
    "Advanced settings" : "Avanserte innstillinger",
    "Allow users to mount external storage" : "Tillat at brukere kobler opp eksterne lagre",
    "Are you sure you want to delete this external storage" : "Er du sikker på at du vil slette denne eksterne lagringsplassen?",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Noen av de oppsatte eksterne oppkoblingspunktene er ikke tilkoblet. Klikk på de røde raden(e) for mer informasjon.",
    "OpenStack" : "OpenStack",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" er ikke installert. Oppkobling av %s er ikke mulig. Spør din systemadministrator om å installere det.",
    "Allow users to mount the following external storage" : "Tillat brukere å koble opp følgende eksterne lagring"
},
"nplurals=2; plural=(n != 1);");
